@@ -27,3 +27,5 @@ char * current_time(void);
 void delay(long ms);
 long string_to_long(char *string);
 int ctrl_key_code(unsigned char key);
+void alert_connect(void);
+void alert_disconnect(void);
