@@ -21,22 +21,13 @@
 
 #pragma once
 
+#include <stdint.h>
 #include <stdbool.h>
 #include <limits.h>
 #include <termios.h>
 #include <sys/param.h>
-
-enum timestamp_t
-{
-    TIMESTAMP_NONE,
-    TIMESTAMP_24HOUR,
-    TIMESTAMP_24HOUR_START,
-    TIMESTAMP_24HOUR_DELTA,
-    TIMESTAMP_ISO8601,
-    TIMESTAMP_END,
-};
-
-enum timestamp_t timestamp_option_parse(const char *arg);
+#include "timestamp.h"
+#include "alert.h"
 
 /* Options */
 struct option_t
@@ -67,6 +58,15 @@ struct option_t
     bool hex_mode;
     unsigned char prefix_code;
     unsigned char prefix_key;
+    bool response_wait;
+    int response_timeout;
+    bool mute;
+    bool rs485;
+    uint32_t rs485_config_flags;
+    int32_t rs485_delay_rts_before_send;
+    int32_t rs485_delay_rts_after_send;
+    enum alert_t alert;
+    bool complete_sub_configs;
 };
 
 extern struct option_t option;
